#
# spec file for package pnpm
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# to avoid empty debugfiles error on some distros
%global debug_package %{nil}
# The internal dependency generator adds lots of unnecessary Requires:
# and strange Provides: own(foo) because it slurps in all package.json
%global __nodejs_provides %{nil}
%global __nodejs_requires %{nil}
Name:           pnpm
Version:        10.2.1
Release:        1.1
Summary:        Fast, disk space efficient package manager
License:        MIT
Group:          Development/Languages/Other
URL:            https://pnpm.io/
Source:         https://registry.npmjs.org/%{name}/-/%{name}-%{version}.tgz
BuildRequires:  fdupes
BuildRequires:  nodejs-devel >= 18
BuildRequires:  nodejs-packaging
Requires:       bash
Recommends:     python3
Provides:       npm(%{name}) = %{version}
BuildArch:      noarch

%description
pnpm is a package manager for node.js

%package bash-completion
Summary:        Bash completion for %{name}
Group:          System/Shells
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Group:          System/Shells
Requires:       zsh
Supplements:    (%{name} and zsh)

%description zsh-completion
Zsh command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Group:          System/Shells
Requires:       fish
Supplements:    (%{name} and fish)

%description fish-completion
Fish command line completion support for %{name}.

%prep
%setup -q -n package

%build
# nothing to do

%install
%nodejs_install

# PATCH FILES

fix_executable() { chmod 775 "$1"; sed -i '1 s|^\(#!.*/\)env |\1|' "$1"; }
export -f fix_executable

# Patch hashbang in pnpm
sed -i -e 's|#!%{_bindir}/env node|#!%{_bindir}/node|' %{buildroot}%{nodejs_sitelib}/pnpm/bin/*

sed -i '1 s|^\(#!.*/\)env |\1|' %{buildroot}%{nodejs_sitelib}/pnpm/dist/node-gyp-bin/node-gyp

# Non-executable scripts
find %{buildroot}%{nodejs_sitelib}/pnpm/dist/node_modules -type f -path '*/bin/*' \
    -exec sh -c 'fix_executable {}' \;
fix_executable %{buildroot}%{nodejs_sitelib}/pnpm/dist/node_modules/glob/dist/esm/bin.mjs

# Remove unnecessary shebangs
sed -i '1!b;\|#!/|d' %{buildroot}%{nodejs_sitelib}/pnpm/dist/node_modules/glob/dist/esm/bin.d.mts
find %{buildroot}%{nodejs_sitelib}/pnpm/dist/node_modules/node-gyp/gyp -type f \
    -exec sed -i '1!b;\|#!/|d' {} \;

# SHELL COMPLETION

mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
%{buildroot}%{_bindir}/pnpm completion bash > %{buildroot}%{_datadir}/bash-completion/completions/%{name}
mkdir -p %{buildroot}%{_datadir}/zsh/site-functions
%{buildroot}%{_bindir}/pnpm completion zsh > %{buildroot}%{_datadir}/zsh/site-functions/_%{name}
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
%{buildroot}%{_bindir}/pnpm completion fish > %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish

# CLEANUP

# Hidden files
find %{buildroot}%{nodejs_sitelib}/pnpm/dist/node_modules -type f -name '.*' -delete

# Hidden directories
find %{buildroot}%{nodejs_sitelib}/pnpm/dist/node_modules -type d -name '.*' -print0 | xargs -0 -n1 rm -rvf

# Non-Linux files
rm -rf %{buildroot}%{nodejs_sitelib}/pnpm/dist/vendor
rm -f %{buildroot}%{nodejs_sitelib}/pnpm/dist/reflink.{darwin,win32}*.node
rm -f %{buildroot}%{nodejs_sitelib}/pnpm/dist/node_modules/node-gyp/macOS_*
find %{buildroot}%{nodejs_sitelib}/pnpm/dist -type f \
    \( -name '*.cmd' -o -name '*.bat' -o -name '*.ps1' \) -delete

%fdupes %{buildroot}

%check

%files
%license LICENSE
%doc README.md
%{_bindir}/pnp{m,x}
%{nodejs_sitelib}

%files bash-completion
%{_datadir}/bash-completion/

%files zsh-completion
%{_datadir}/zsh/

%files fish-completion
%{_datadir}/fish/

%changelog
* Sat Feb  8 2025 Avindra Goolcharan <avindra@opensuse.org>
- update to 10.2.1:
  * Don't read a package from side-effects cache if it isn't
    allowed to be built #9042.
  * pnpm approve-builds should work, when executed from a
    subdirectory of a workspace #9042.
  * pnpm deploy --legacy should work without injected dependencies
  * Add information about how to deploy without "injected
    dependencies" to the "pnpm deploy" error message.
- includes 10.2.0:
  * Packages executed via pnpm dlx and pnpm create are allowed to
    be built (run postinstall scripts) by default.
  * Quote args for scripts with shell-quote to support new lines
    (on POSIX only) #8980.
  * Fix a bug in which pnpm deploy fails to read the correct
    projectId when the deploy source is the same as the workspace directory #9001.
  * Proxy settings should be respected, when resolving Git-hosted
    dependencies #6530.
  * Prevent overrides from adding invalid version ranges to
    peerDependencies by keeping the peerDependencies and
    overriding them with prod dependencies #8978.
  * Sort the package names in the "pnpm.onlyBuiltDependencies"
    list saved by pnpm approve-builds.
* Fri Jan 31 2025 Avindra Goolcharan <avindra@opensuse.org>
- update to 10.1.0:
  * Added a new command for printing the list of dependencies
    with ignored build scripts: pnpm ignored-builds #8963.
  * Added a new command for approving dependencies for running
    scripts during installation: pnpm approve-builds #8963.
  * Added a new setting called optimistic-repeat-install. When
    enabled, a fast check will be performed before proceeding to
    installation. This way a repeat install or an install on a
    project with everything up-to-date becomes a lot faster. But
    some edge cases might arise, so we keep it disabled by
    default for now #8977.
  * Added a new field "pnpm.ignoredBuiltDependencies" for
    explicitly listing packages that should not be built. When a
    package is in the list, pnpm will not print an info message
    about that package not being built #8935.
  * Verify that the package name is valid when executing the
    publish command.
  * When running pnpm install, the preprepare and postprepare
    scripts of the project should be executed #8989.
  * Allow workspace: and catalog: to be part of wider version
    range in peerDependencies.
  * pnpm deploy should inherit the pnpm object from the root
    package.json #8991.
  * Make sure that the deletion of a node_modules in a sub-
    project of a monorepo is detected as out-of-date #8959.
  * Fix infinite loop caused by lifecycle scripts using pnpm to
    execute other scripts during pnpm install with
    verify-deps-before-run=install #8954.
  * Replace strip-ansi with the built-in util.
    stripVTControlCharacters #9009.
  * Do not print patched dependencies as ignored dependencies
    that require a build #8952.
* Fri Jan 10 2025 Avindra Goolcharan <avindra@opensuse.org>
- update to 10.0.0:
  * Lifecycle scripts of dependencies are not executed during
    installation by default! This is a breaking change aimed at
    increasing security. In order to allow lifecycle scripts of
    specific dependencies, they should be listed in the pnpm
    onlyBuiltDependencies field of package.json #8897
  * The pnpm link command now adds overrides to the root package.json. #8653
  * Secure hashing with SHA256
  * Configuration updates
  * Changes to the global store
  * The # character is now escaped in directory names within
    node_modules/.pnpm. #8557
  * Running pnpm add --global pnpm or pnpm add --global @pnpm/exe
    now fails with an error message, directing you to use pnpm
    self-update instead. #8728
  * Dependencies added via a URL now record the final resolved
    URL in the lockfile, ensuring that any redirects are fully
    captured. #8833
  * The pnpm deploy command now only works in workspaces that
    have inject-workspace-packages=true. This limitation is
    introduced to allow us to create a proper lockfile for the
    deployed project using the workspace lockfile.
  * Removed conversion from lockfile v6 to v9. If you need v6-to-
    v9 conversion, use pnpm CLI v9.
  * pnpm test now passes all parameters after the test keyword
    directly to the underlying script. This matches the behavior
    of pnpm run test. Previously you needed to use the -- prefix. #8619
  * node-gyp updated to version 11.
  * pnpm deploy now tries creating a dedicated lockfile from a
    shared lockfile for deployment. It will fallback to
    deployment without a lockfile if there is no shared lockfile
    or force-legacy-deploy is set to true.
  * Added support for a new type of dependencies called
    "configurational dependencies". These dependencies are
    installed before all the other types of dependencies (befor
    "dependencies", "devDependencies", "optionalDependencies").
  * New verify-deps-before-run setting. This setting controls how
    pnpm checks node_modules before running scripts #8836
  * On repeated installs, pnpm performs a quick check to ensure
    node_modules is up to date. #8838
  * pnpm add integrates with default workspace catalog: #8640
  * pnpm dlx now resolves packages to their exact versions and
    uses these exact versions for cache keys. This ensures pnpm
    dlx always installs the latest requested packages #8811
  * No node_modules validation on certain commands. Commands that
    should not modify node_modules (e.g., pnpm install --lockfile-
    only) no longer validate or purge node_modules. #8657
  * for full changes, see https://github.com/pnpm/pnpm/releases/tag/v10.0.0
* Mon Jan  6 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.15.3:
  * Fixed the Regex used to find the package manifest during
    packing #8938.
  * pnpm update --filter <pattern> --latest <pkg> should only
    change the specified package for the specified workspace, when
    dedupe-peer-dependents is set to true #8877.
  * Exclude .DS_Store file at patch-commit #8922.
  * Fix a bug in which pnpm patch is unable to bring back old patch
    without specifying @version suffix #8919.
* Mon Dec 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.15.2:
  * Fixed publish/pack error with workspace dependencies with
    relative paths #8904. It was broken in v9.4.0 (398472c).
  * Use double quotes in the command suggestion by pnpm patch on
    Windows #7546.
  * Do not fall back to SSH, when resolving a git-hosted package if
    git ls-remote works via HTTPS #8906.
  * Improve how packages with blocked lifecycle scripts are
    reported during installation. Always print the list of ignored
    scripts at the end of the output. Include a hint about how to
    allow the execution of those packages.
* Sun Dec 22 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.15.1:
  * pnpm remove should not link dependencies from the workspace,
    when link-workspace-packages is set to false #7674
  * Installation with hoisted node_modules should not fail, when
    a dependency has itself in its own peer dependencies #8854
* Sat Dec  7 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.15.0:
  * Metadata directory version bumped to force fresh cache after
    we shipped a fix to the metadata write function. This change
    is backward compatible as install doesn't require a metadata cache
  * pnpm update --global should not crash if there are no any
    global packages installed #7898
  * Fix an exception when running pnpm update --interactive if
    catalogs are used.
* Sat Nov 30 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.14.4:
  * Don't ever save mutated metadata to the metadata cache
- includes 9.14.3:
  * Some commands should ignore the packageManager field check of
    package.json #7959
* Wed Nov 20 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.14.2:
    pnpm publish --json should work #8788
- includes 9.14.1:
  * Added support for pnpm pack --json to print packed tarball
    and contents in JSON format #8765
  * pnpm exec should print a meaningful error message when no
    command is provided #8752
  * pnpm setup should remove the CLI from the target location
    before moving the new binary #8173
  * Fix ERR_PNPM_TARBALL_EXTRACT error while installing a
    dependency from GitHub having a slash in branch name #7697
  * Don't crash if the use-node-version setting is used and the
    system has no Node.js installed #8769
  * Convert settings in local .npmrc files to their correct types.
    For instance, child-concurrency should be a number, not a string #5075
  * pnpm should fail if a project requires a different package
    manager even if manage-package-manager-versions is set to true
  * pnpm init should respect the --dir option #8768
- includes 9.14.0:
  * chore: use verify-deps-before-run
  * fix(init): --dir option should be respected (#8768)
  * feat: support json format output in pnpm pack (#8765)
  * fix: pnpm exec should specify command (#8774)
  * fix: proper types of settings in local .npmrc files (#8775)
  * fix: ERR_PNPM_TARBALL_EXTRACT when the URL's hash contains a slash
  * fix: the CLI should fail if a different package manager is
    required by the project
  * fix: ETXTBSY error on running setup (#8780)
  * feat: add linux-riscv64 build (#8779)
  * fix: remove link to X from update notifier (#8773)
  * docs: update sponsors
  * fix: upgrade cross-sapwn (#8782)
  * fix: don't crash when use-node-version is set and there is no node.js
  * docs: update changesets
* Sat Nov 16 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.13.2:
  * Detection of circular peer dependencies should not crash with
    aliased dependencies #8759. Fixes a regression introduced in
    the previous version.
  * Fix race condition of symlink creations caused by multiple
    parallel dlx processes.
* Thu Nov 14 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.13.1:
  * Fixed some edge cases where resolving circular peer
    dependencies caused a dead lock #8720
* Wed Nov 13 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.13.0:
  * The self-update now accepts a version specifier to install a
    specific version of pnpm.
  * Fix Cannot read properties of undefined (reading 'name') that
    is printed while trying to render the missing peer
    dependencies warning message #8538
* Fri Nov  8 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.12.3:
  * Don't purge node_modules, when typing "n" in the prompt that
    asks whether to remove node_modules before installation #8655
  * Fix a bug causing pnpm to infinitely spawn itself when manage-
    package-manager-versions=true is set and the .tools directory is corrupt
  * Use crypto.hash, when available, for improved performance #8629
  * Fixed a race condition in temporary file creation in the
    store by including worker thread ID in filename. Previously,
    multiple worker threads could attempt to use the same
    temporary file. Temporary files now include both process ID
    and thread ID for uniqueness #8703
  * All commands should read settings from the package.json at
    the root of the workspace #8667
  * When manage-package-manager-versions is set to true, errors
    spawning a self-managed version of pnpm will now be shown
    (instead of being silent)
  * Pass the find command to npm, it is an alias for npm search
- includes 9.12.2:
  * When checking whether a file in the store has executable
    permissions, the new approach checks if at least one of the
    executable bits (owner, group, and others) is set to 1.
    Previously, a file was incorrectly considered executable only
    when all the executable bits were set to 1. This fix ensures
    that files with any executable permission, regardless of the
    user class, are now correctly identified as executable #8546
* Tue Oct  8 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.12.1:
  * pnpm update --latest should not update the automatically
    installed peer dependencies #6657
  * pnpm publish should be able to publish from a local tarball #7950
  * Prevent EBUSY errors caused by creating symlinks in parallel
    dlx processes #8604
  * Fix maximum call stack size exceeded error related to
    circular workspace dependencies #8599
* Fri Oct  4 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.12.0:
  * Fix peer dependency resolution dead lock #8570. This change
    might change some of the keys in the snapshots field inside
    pnpm-lock.yaml but it should happen very rarely.
  * pnpm outdated command supports now a --sort-by=name option
    for sorting outdated dependencies by package name #8523
  * Added the ability for overrides to remove dependencies by
    specifying "-" as the field value #8572
  * Fixed an issue where pnpm list --json pkg showed "private":
    false for a private package #8519
  * Packages with libc that differ from pnpm.
    supportedArchitectures.libc are not downloaded #7362
  * Prevent ENOENT errors caused by running store prune in parallel #8586
  * Add issues alias to pnpm bugs #8596
* Sat Sep 21 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.11.0:
  * Experimental: added pnpm cache commands for inspecting the
    metadata cache #8512
  * Fix a regression in which pnpm deploy with node-linker=hoisted
    produces an empty node_modules directory #6682
  * pnpm deploy should work in workspace with shared-workspace-lockfile=false #8475
  * Don't print a warning when linking packages globally #4761
* Wed Sep 11 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.10.0:
  * Support for a new CLI flag, --exclude-peers, added to the
    list and why commands. When --exclude-peers is used, peer
    dependencies are not printed in the results, but dependencies
    of peer dependencies are still scanned #8506.
  * Added a new setting to package.json at pnpm.auditConfig.
    ignoreGhsas for ignoring vulnerabilities by their GHSA code #6838.
  * Throw an exception if pnpm switches to the same version of itself.
  * Reduce memory usage during peer dependencies resolution.
* Mon Sep  2 2024 Virinas-code <Virinas-code@opensuse.org>
- update to version 9.9.0:
  * https://github.com/pnpm/pnpm/compare/v9.8.0...v9.9.0
  * Minor breaking change. We had to optimize how we resolve peer
    dependencies in order to fix some infinite loops and
    out-of-memory errors during peer dependencies resolution.
  * pnpm deploy should write the node_modules/.modules.yaml to the
    node_modules directory within the deploy directory #7731
  * Don't override a symlink in node_modules if it already points
    to the right location pnpm/symlink-dir#54
- changes from 9.8.0:
  * https://github.com/pnpm/pnpm/compare/v9.7.1...v9.8.0
  * Added a new command for upgrading pnpm itself when it isn't
    managed by Corepack: pnpm self-update. This command will work,
    when pnpm was installed via the standalone script from the pnpm
    installation page #8424
  * CLI tools installed in the root of the workspace should be
    added to the PATH, when running scripts and use-node-version is
    set
  * pnpm setup should never switch to another version of pnpm
  * Ignore non-string value in the os, cpu, libc fields, which
    checking optional dependencies #8431
  * Remember the state of edit dir, allow running pnpm patch-commit
    the second time without having to re-run pnpm patch
- changes from 9.7.1:
  * https://github.com/pnpm/pnpm/compare/v9.7.0...v9.7.1
  * Fixed passing public-hoist-pattern and hoist-pattern via env
    variables #8339
  * pnpm setup no longer creates Batch/Powershell scripts on Linux
    and macOS #8418
  * When dlx uses cache, use the real directory path not the
    symlink to the cache #8421
  * pnpm exec now supports executionEnv #8356
  * Remove warnings for non-root pnpm field, add warnings for
    non-root pnpm subfields that aren't executionEnv #8143
  * Replace semver in "peerDependency" with workspace protocol
    [#8355]
  * Fix a bug in patch-commit in which relative path is rejected
    [#8405]
  * Update Node.js in @pnpm/exe to v20
- changes from 9.7.0:
  * https://github.com/pnpm/pnpm/compare/v9.6.0...v9.7.0
  * Added pnpm version management. If the
    manage-package-manager-versions setting is set to true, pnpm
    will switch to the version specified in the packageManager
    field of package.json #8363
  * Added the ability to apply patch to all versions #8337
  * Change the default edit dir location when running pnpm patch
    from a temporary directory to
    node_modules/.pnpm_patches/pkg[@version] to allow the code
    editor to open the edit dir in the same file tree as the main
    project #8379.
  * Substitute environment variables in config keys #6679
  * pnpm install should run node-gyp rebuild if the project has a
    binding.gyp file even if the project doesn't have an install
    script #8293
  * Print warnings to stderr #8342
  * Peer dependencies of optional peer dependencies should be
    automatically installed #8323
* Thu Jul 25 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.6.0:
  * Support specifying node version (via pnpm.executionEnv.nodeVersion
    in package.json) for running lifecycle scripts per each package
    in a workspace #6720
  * Overrides now support the catalogs: protocol #8303
  * The pnpm deploy command now supports the catalog: protocol #8298
  * The pnpm outdated command now supports the catalog: protocol #8304
  * Correct the error message when trying to run pnpm patch
    without node_modules/.modules.yaml #8257
  * Silent reporting fixed with the pnpm exec command #7608
  * Add registries information to the calculation of dlx cache hash #8299
* Tue Jul  9 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.5.0:
  * Added support for catalogs #8122
  * Read authentication information from .npmrc in the current
    directory when running dlx #7996
  * Updated @pnpm/tabtab to v0.5.4, enabling zsh autocomplete
    lazy loading #8236
  * Installation with filtering will now work, when dedupe-peer-
    dependents is set to true #6300
  * Fixed dlx not actually using the Node.js version specified by
  - -use-node-version.
* Sat Jul  6 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.4.0:
  * Some registries allow the exact same content to be published
    under different package names and/or versions. This breaks
    the validity checks of packages in the store. To avoid errors
    when verifying the names and versions of such packages in the
    store, you may now set the strict-store-pkg-content-check
    setting to false #4724
  * Fix package-manager-strict-version missing in config #8195
  * If install is performed on a subset of workspace projects,
    always create an up-to-date lockfile first. So, a partial
    install can be performed only on a fully resolved (non-partial)
    lockfile #8165
  * Handle workspace protocol with any semver range specifier,
    when used in peer dependencies #7578
* Fri Jun 14 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.3.0:
  * Semi-breaking. Dependency key names in the lockfile are
    shortened if they are longer than 1000 characters. We don't
    expect this change to affect many users. Affected users most
    probably can't run install successfully at the moment. This
    change is required to fix some edge cases in which installation
    fails with an out-of-memory error or "Invalid string length
    (RangeError: Invalid string length)" error. The max allowed
    length of the dependency key can be controlled with the peers-
    suffix-max-length setting #8177.
  * Set reporter-hide-prefix to true by default for pnpm exec. In
    order to show prefix, the user now has to explicitly set reporter
  - hide-prefix=false #8174.
- changes from 9.2.0:
  * If package-manager-strict-version is set to true, pnpm will
    fail if its version doesn't exactly match the version in the
    "packageManager" field of package.json.
  * Update @yarnpkg/pnp to the latest version, fixing issue with
    node: imports #8161.
  * Deduplicate bin names to prevent race condition and corrupted
    bin scripts #7833.
  * pnpm doesn't fail if its version doesn't match the one
    specified in the "packageManager" field of package.json #8087.
  * exec now also streams prefixed output when --recursive or
  - -parallel is specified just as run does #8065.
- changes from 9.1.4:
  * Improved the performance of the resolution stage by changing
    how missing peer dependencies are detected #8144.
- changes from 9.1.3:
  * Fix a bug in which a dependency that is both optional for one
    package but non-optional for another is omitted when optional=false #8066.
  * Clear resolution cache before starting peer dependencies resolution #8109.
  * Reduce memory usage by peer dependencies resolution #8072.
* Tue May 21 2024 draskmont@protonmail.com
- update to version 9.1.2
- require nodejs >= 18
* Sat Apr 27 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.0.6:
  * Lockfiles that have git-hosted dependencies specified should
    be correctly converted to the new lockfile format #7990.
  * Don't upgrade the lockfile format on pnpm install
  - -frozen-lockfile #7991.
- includes version 9.0.5:
  * Lockfiles with local or git-hosted dependencies are now
    successfully converted to the new lockfile format #7955.
  * Resolve peer dependencies correctly, when they have
    prerelease versions #7977.
  * Fix aliased dependencies resolution on repeat install with
    existing lockfile, when the aliased dependency doesn't
    specify a version or range #7957.
  * The lockfile should be saved in the new format even if it is
    up-to-date.
- run spec-cleaner
* Sat Apr 20 2024 draskmont@protonmail.com
- update to version 9.0.4
- Added shell completion subpackages for bash, zsh and fish
- Removed python2 dependency
- Prevent packaging of executable files for other OS.
- Cleaned up specfile:
  * Removed some unused tags, macros and redudant requirements
  * Added licensing header
  * Fixed rpmlint errors and warnings
- Removed unused _service file
- Restored changelog
* Thu Jan 25 2024 Marcel Kuehlhorn <tux93@opensuse.org>
- update to version 8.14.3
  * https://github.com/pnpm/pnpm/compare/v8.4.0...v8.14.3
* Mon Jan 14 2019 John Vandenberg <jayvdb@gmail.com>
- initial revision for pnpm 2.25.1
